"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable no-var */
const _1 = require(".");
const jest_fetch_mock_1 = __importDefault(require("jest-fetch-mock"));
const v2_1 = require("./v2");
const v3_1 = require("./v3");
const embed_params_1 = require("./embed.params");
jest_fetch_mock_1.default.enableMocks();
const REQUEST_URL = "https://widget-data.stackla.com/widgets/123/version";
const STAGING_REQUEST_URL = "https://widget-data.teaser.stackla.com/widgets/123/version";
describe("load embed code", () => {
    beforeEach(() => {
        jest_fetch_mock_1.default.resetMocks();
    });
    it("should return the correct embed code for v2", async () => {
        jest_fetch_mock_1.default.mockIf(REQUEST_URL, async () => {
            return JSON.stringify({ version: 2 });
        });
        const createdDiv = document.createElement("div");
        await (0, _1.embed)({
            widgetId: "123",
            root: createdDiv,
            dataProperties: {
                foo: "bar",
                baz: 123
            },
            environment: "production"
        });
        expect(createdDiv.innerHTML).toContain((0, v2_1.getWidgetV2EmbedCode)({ foo: "bar", baz: 123, hash: "123" }));
        expect(createdDiv.innerHTML).toMatchSnapshot();
    });
    it("should test staging for v2", async () => {
        jest_fetch_mock_1.default.mockIf(STAGING_REQUEST_URL, async () => {
            return JSON.stringify({ version: 2 });
        });
        const createdDiv = document.createElement("div");
        await (0, _1.embed)({
            widgetId: "123",
            root: createdDiv,
            dataProperties: {
                foo: "bar",
                baz: 123
            },
            environment: "staging"
        });
        expect(window.stackWidgetDomain).toBe("widgetapp.teaser.stackla.com");
    });
    it("should test production for v2", async () => {
        jest_fetch_mock_1.default.mockIf(REQUEST_URL, async () => {
            return JSON.stringify({ version: 2 });
        });
        const createdDiv = document.createElement("div");
        await (0, _1.embed)({
            widgetId: "123",
            root: createdDiv,
            dataProperties: {
                foo: "bar",
                baz: 123
            },
            environment: "production"
        });
        expect(window.stackWidgetDomain).toBe("widgetapp.stackla.com");
    });
    it("should return the correct embed code for v3", async () => {
        jest_fetch_mock_1.default.mockIf(REQUEST_URL, async () => {
            return JSON.stringify({ version: 3 });
        });
        const createdDiv = document.createElement("div");
        await (0, _1.embed)({
            widgetId: "123",
            root: createdDiv,
            dataProperties: {
                foo: "bar",
                baz: 123
            },
            environment: "production"
        });
        expect(createdDiv.innerHTML).toContain((0, v3_1.getWidgetV3EmbedCode)({ foo: "bar", baz: 123, wid: "123" }));
        expect(createdDiv.innerHTML).toContain(`<div id="ugc-widget" data-foo="bar" data-baz="123" data-wid="123"></div>`);
    });
    it("should throw an error if the version is not supported", async () => {
        jest_fetch_mock_1.default.mockIf(REQUEST_URL, async () => {
            return JSON.stringify({ version: 4 });
        });
        const createdDiv = document.createElement("div");
        try {
            await (0, _1.embed)({
                widgetId: "123",
                root: createdDiv,
                dataProperties: {
                    foo: "bar",
                    baz: 123
                },
                environment: "production"
            });
        }
        catch (error) {
            expect(error).toBe("Failed to embed widget. No widget code accessible with version 4");
        }
    });
    it("should skip the fetch call if the version is provided", async () => {
        const createdDiv = document.createElement("div");
        await (0, _1.embed)({
            widgetId: "123",
            root: createdDiv,
            version: 3,
            dataProperties: {
                foo: "bar",
                baz: 123
            },
            environment: "production"
        });
        expect(jest_fetch_mock_1.default).not.toHaveBeenCalled();
        expect(createdDiv.innerHTML).toContain((0, v3_1.getWidgetV3EmbedCode)({ foo: "bar", baz: 123, wid: "123" }));
        expect(createdDiv.innerHTML).toContain('<div id="ugc-widget" data-foo="bar" data-baz="123" data-wid="123"></div>');
    });
    it("should test param string method", async () => {
        const params = (0, embed_params_1.generateDataHTMLStringByParams)({ foo: "bar", baz: 123, wid: "123" });
        expect(params).toBe(' data-foo="bar" data-baz="123" data-wid="123"');
    });
    it("should deal with malicious payloads", async () => {
        const createdDiv = document.createElement("div");
        await (0, _1.embed)({
            widgetId: "123",
            root: createdDiv,
            version: 3,
            dataProperties: {
                foo: "bar",
                baz: 123,
                '><img src="x" onerror="alert(1)">': '"><img src="x" onerror="alert(1)">'
            },
            environment: "production"
        });
        expect(jest_fetch_mock_1.default).not.toHaveBeenCalled();
        expect(createdDiv.innerHTML).toContain(
        // eslint-disable-next-line no-useless-escape
        `<div id=\"ugc-widget\" data-foo=\"bar\" data-baz=\"123\" data-&gt;<img=\"\" src=\"x\">=\"\"&gt;<img src=\"x\">\" data-wid=\"123\"&gt;</div>`);
    });
    it("should deal with malicious payloads", async () => {
        const createdDiv = document.createElement("div");
        await (0, _1.embed)({
            widgetId: "123",
            root: createdDiv,
            version: 3,
            dataProperties: {
                foo: "bar",
                baz: 123,
                tags: "ext%3A8794633601273"
            },
            environment: "production"
        });
        expect(createdDiv.innerHTML).toBe(
        // eslint-disable-next-line no-useless-escape
        `<div id=\"ugc-widget\" data-foo=\"bar\" data-baz=\"123\" data-tags=\"ext%3A8794633601273\" data-wid=\"123\"></div>`);
    });
});
//# sourceMappingURL=embed.spec.js.map