"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const handlebars_1 = __importDefault(require("handlebars"));
const tile_helper_1 = require("./tile.helper");
const join_helper_1 = require("./join.helper");
beforeAll(() => {
    (0, tile_helper_1.loadTileHelper)(handlebars_1.default);
    (0, join_helper_1.loadJoinHelper)(handlebars_1.default);
});
describe("tile helper", () => {
    it("should render div with default class and style inferred from context", () => {
        const template = handlebars_1.default.compile(`{{#tile}}<p>{{title}}</p>{{/tile}}`);
        const context = {
            id: "1234",
            media: "video",
            title: "Video Title"
        };
        const output = template(context);
        expect(output).toEqual('<div class="tile-video ugc-tile" data-id="1234"><p>Video Title</p></div>');
    });
    it("should merge custom class and style with default values", () => {
        const template = handlebars_1.default.compile(`{{#tile class="custom-class" style="color: red;"}}<p>{{title}}</p>{{/tile}}`);
        const context = {
            id: "5678",
            media: "image",
            title: "Hello world!"
        };
        const output = template(context);
        expect(output).toEqual('<div class="tile-image ugc-tile custom-class" data-id="5678" style="color: red;"><p>Hello world!</p></div>');
    });
    it("should work when no custom class or style is provided", () => {
        const template = handlebars_1.default.compile(`{{#tile}}<p>{{title}}</p>{{/tile}}`);
        const context = {
            id: "9101",
            media: "video",
            title: "Youtube Title"
        };
        const output = template(context);
        expect(output).toEqual('<div class="tile-video ugc-tile" data-id="9101"><p>Youtube Title</p></div>');
    });
    it("should handle empty context values gracefully", () => {
        const template = handlebars_1.default.compile(`{{#tile}}<p>{{title}}</p>{{/tile}}`);
        const context = {
            id: "",
            media: "",
            title: "Another one"
        };
        const output = template(context);
        expect(output).toEqual('<div class="tile- ugc-tile" data-id=""><p>Another one</p></div>');
    });
    it("should allow only custom class and no style", () => {
        const template = handlebars_1.default.compile(`{{#tile class="my-custom-class"}}<p>{{title}}</p>{{/tile}}`);
        const context = {
            id: "1112",
            media: "image",
            title: "Hello world!"
        };
        const output = template(context);
        expect(output).toEqual('<div class="tile-image ugc-tile my-custom-class" data-id="1112"><p>Hello world!</p></div>');
    });
    it("should allow only custom style and no class", () => {
        const template = handlebars_1.default.compile(`{{#tile style="margin: 10px;"}}<p>{{title}}</p>{{/tile}}`);
        const context = {
            id: "1314",
            media: "video",
            title: "Hello world!"
        };
        const output = template(context);
        expect(output).toEqual('<div class="tile-video ugc-tile" data-id="1314" style="margin: 10px;"><p>Hello world!</p></div>');
    });
    it("should also render additional attrs", () => {
        const template = handlebars_1.default.compile(`{{#tile style="margin: 10px;" data-hash="plugin-hash"}}<p>{{title}}</p>{{/tile}}`);
        const context = {
            id: "1314",
            media: "video",
            title: "Hello world!"
        };
        const output = template(context);
        expect(output).toEqual('<div class="tile-video ugc-tile" data-hash="plugin-hash" data-id="1314" style="margin: 10px;"><p>Hello world!</p></div>');
    });
    it("should render multiple tiles using the tpl-tile partial", () => {
        handlebars_1.default.registerPartial("tpl-tile", `{{#tile style="margin: 10px;" data-hash=(join "plugin-" @index)}}<p>{{title}}</p>{{/tile}}`);
        const hbsTemplate = handlebars_1.default.compile(`
      {{#tiles}}
        {{>tpl-tile}}
      {{/tiles}}
    `);
        const context = {
            tiles: [
                {
                    id: "1234",
                    media: "video",
                    title: "Video Title"
                },
                {
                    id: "5678",
                    media: "image",
                    title: "Image Title"
                }
            ]
        };
        const output = hbsTemplate(context);
        const expectedOutput = `
      <div class="tile-video ugc-tile" data-hash="plugin-0" data-id="1234" style=" margin: 10px;"><p>Video Title</p></div>        
      <div class="tile-image ugc-tile" data-hash="plugin-1" data-id="5678" style=" margin: 10px;"><p>Image Title</p></div>
    `.replaceAll(/[\r\n\s]+/g, "");
        expect(output.replaceAll(/[\r\n\s]+/g, "")).toEqual(expectedOutput);
    });
});
//# sourceMappingURL=tile.helper.spec.js.map