"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.playMediaOnLoad = playMediaOnLoad;
exports.controlVideoPlayback = controlVideoPlayback;
exports.triggerPlay = triggerPlay;
exports.triggerPause = triggerPause;
exports.getSwiperVideoElement = getSwiperVideoElement;
exports.setupYoutubeEvents = setupYoutubeEvents;
exports.setupTikTokPlayerReadyEvent = setupTikTokPlayerReadyEvent;
exports.playActiveMediaTileOnLoad = playActiveMediaTileOnLoad;
exports.setupVideoEvents = setupVideoEvents;
const expanded_swiper_loader_1 = require("./expanded-swiper.loader");
const swiper_1 = require("../../extensions/swiper");
const swiper_extension_1 = require("../../extensions/swiper/swiper.extension");
const tiktok_message_1 = require("./tiktok-message");
let tiktokDefaultPlayed = false;
/**
 * Play the video/audio attached to the slide on load where the element is a media element (video/youtube/tiktok)
 */
async function playMediaOnLoad(sdk) {
    const swiper = (0, swiper_1.getInstance)(sdk, `expanded`);
    if (swiper) {
        const activeElementData = getSwiperVideoElement(sdk, swiper, swiper.realIndex);
        triggerPlay(sdk, activeElementData);
    }
}
/**
 * Play/Pause the video/audio attached to the slide on navigation where the element is a media element (video/youtube/tiktok)
 * @param { Swiper } swiper - the swiper element
 */
async function controlVideoPlayback(sdk, swiper) {
    const activeElement = getSwiperVideoElement(sdk, swiper, swiper.realIndex);
    const previousElement = getSwiperVideoElement(sdk, swiper, swiper.previousIndex);
    if (activeElement) {
        triggerPlay(sdk, activeElement);
    }
    if (previousElement) {
        triggerPause(previousElement);
    }
}
/**
 * Trigger media play for different media element sources ("video", "youtube", "tiktok")
 *
 * @param elementData - the media container element and the source
 * @param elementData.element - the container element of the media (video tag or iframe.contentWindow)
 * @param elementData.source - the media source (video for custom video source, youtube/tiktok)
 */
function triggerPlay(sdk, elementData) {
    if (!elementData) {
        console.warn("elementData is required");
        return;
    }
    const swiperExpandedId = `expanded`;
    switch (elementData.source) {
        case "video": {
            const videoElement = elementData.element;
            videoElement.play();
            if ((0, swiper_extension_1.getSwiperContainer)(sdk, swiperExpandedId)?.muted) {
                videoElement.muted = true;
            }
            else {
                videoElement.muted = false;
            }
            break;
        }
        case "youtube": {
            const YoutubeContentWindow = elementData.element;
            YoutubeContentWindow.play();
            if ((0, swiper_extension_1.getSwiperContainer)(sdk, swiperExpandedId)?.muted) {
                YoutubeContentWindow.mute();
            }
            else {
                YoutubeContentWindow.unMute();
            }
            break;
        }
        case "tiktok": {
            const tiktokFrameWindow = elementData.element;
            (0, tiktok_message_1.playTiktokVideo)(tiktokFrameWindow);
            if ((0, swiper_extension_1.getSwiperContainer)(sdk, swiperExpandedId)?.muted) {
                (0, tiktok_message_1.muteTiktokVideo)(tiktokFrameWindow);
            }
            else {
                (0, tiktok_message_1.unMuteTiktokVideo)(tiktokFrameWindow);
            }
            break;
        }
        default:
            throw new Error(`unsupported video source ${elementData.source}`);
    }
}
/**
 * Trigger media pause for different element sources ("video", "youtube", "tiktok")
 *
 * @param elementData - the media container element and the source
 * @param elementData.element - the container element of the media (video tag or iframe.contentWindow)
 * @param elementData.source - the media source (video for custom video source, youtube/tiktok)
 */
function triggerPause(elementData) {
    if (!elementData) {
        throw new Error("elementData is required");
    }
    switch (elementData.source) {
        case "video": {
            const videoElement = elementData.element;
            videoElement.pause();
            videoElement.currentTime = 0;
            break;
        }
        case "youtube": {
            const YoutubeContentWindow = elementData.element;
            YoutubeContentWindow.pause();
            YoutubeContentWindow.reset();
            break;
        }
        case "tiktok": {
            const tiktokFrameWindow = elementData.element;
            (0, tiktok_message_1.pauseTiktokVideo)(tiktokFrameWindow);
            break;
        }
        default:
            throw new Error(`unsupported video source ${elementData.source}`);
    }
}
/**
 * Get swiper video/audio element at the provided index.
 *
 * @param { Swiper } swiper - the swiper element
 * @param { number } index - index of the slide to be returned
 * @param { number } isStory - if it is story widget
 * @returns the video/iframe element or undefined if the element at index is not a video/audio
 */
function getSwiperVideoElement(sdk, swiper, index, isStory = false) {
    const element = swiper.slides[index];
    const tileId = (0, expanded_swiper_loader_1.getTileIdFromSlide)(swiper, index);
    const youtubeId = element.getAttribute("data-yt-id");
    if (!tileId) {
        throw new Error(`Failed to find tile id for the slide at index ${index}`);
    }
    const tile = sdk.getTileById(tileId);
    if (!tile) {
        throw new Error(`Failed to find tile by tile id ${tileId} in getSwiperVideoElement`);
    }
    const media = tile.media;
    if (media !== "video" && media !== "short") {
        return undefined;
    }
    if (youtubeId) {
        const youtubeFrame = element.querySelector(`iframe#yt-frame-${tileId}-${youtubeId}`);
        if (youtubeFrame) {
            return { element: youtubeFrame.contentWindow, source: "youtube" };
        }
    }
    const tiktokId = element.getAttribute("data-tiktok-id");
    if (tiktokId) {
        const tiktokFrame = element.querySelector(`iframe#tiktok-frame-${tileId}-${tiktokId}`);
        if (tiktokFrame && tiktokFrame.contentWindow) {
            return { element: tiktokFrame.contentWindow, source: "tiktok" };
        }
    }
    const videoElement = element.querySelector(`${isStory ? "" : " .panel .panel-left"} .video-content-wrapper video`);
    if (videoElement) {
        return { element: videoElement, source: "video" };
    }
    return undefined;
}
/**
 * Setup onload and onerror (yt-video-error) events for youtube media
 *
 * @param { Element } tile - the tile element
 * @param { HTMLElement } widgetSelector - the container of swiper element
 */
function setupYoutubeEvents(sdk, tile, widgetSelector) {
    const tileId = tile.getAttribute("data-id");
    const youtubeId = tile.getAttribute("data-yt-id");
    if (youtubeId && tileId) {
        const youtubeFrame = tile.querySelector(`iframe#yt-frame-${tileId}-${youtubeId}`);
        youtubeFrame?.addEventListener("load", () => {
            playActiveMediaTileOnLoad(sdk, tile, widgetSelector, { name: "data-yt-id", value: youtubeId });
        });
        youtubeFrame?.addEventListener("yt-video-error", () => {
            youtubeFrame.closest(".video-content-wrapper")?.classList.add("hidden");
            tile.querySelector(".video-fallback-content")?.classList.remove("hidden");
        });
    }
}
/**
 * Setup tiktok player events using window.postMessage api
 * All media are paused by defult and only the media in the active slide is played
 */
function setupTikTokPlayerReadyEvent(sdk) {
    tiktokDefaultPlayed = false;
    window.onmessage = (event) => {
        if (event.data["x-tiktok-player"] && event.data.type === "onPlayerReady") {
            const frameWindow = event.source;
            (0, tiktok_message_1.pauseTiktokVideo)(frameWindow);
            if (!tiktokDefaultPlayed) {
                tiktokDefaultPlayed = true;
                setTimeout(() => playMediaOnLoad(sdk), 300);
            }
        }
    };
}
/**
 * Play media associated with currently active tile
 *
 * @param { Element } tile - tile element to check
 * @param { HTMLElement } widgetSelector - the container of the swiper element
 * @param { LookupAttr } lookupAttr - additional attribute lookup options for finding the first slide to load
 * @param { LookupAttr.name } lookupAttr.name - name of the attribute for e.g. data-yt-id or data-tiktok-id
 * @param { LookupAttr.value } lookupAttr.value - required value of the attribute
 */
function playActiveMediaTileOnLoad(sdk, tile, widgetSelector, lookupAttr) {
    if ((0, expanded_swiper_loader_1.isActiveTile)(sdk, tile, widgetSelector, lookupAttr)) {
        playMediaOnLoad(sdk);
    }
}
/**
 * Setup onload and onerror events for custom video source
 *
 * @param { Element } tile - the tile element
 * @param { HTMLElement } widgetSelector - the container of swiper element
 */
function setupVideoEvents(sdk, tile, widgetSelector) {
    const videoSourceElement = tile.querySelector("video.video-content > source");
    if (videoSourceElement) {
        videoSourceElement.addEventListener("load", () => {
            playActiveMediaTileOnLoad(sdk, tile, widgetSelector);
        });
        videoSourceElement.addEventListener("error", () => {
            videoSourceElement.closest(".video-content-wrapper")?.classList.add("hidden");
            tile.querySelector(".video-fallback-content")?.classList.remove("hidden");
        });
    }
}
//# sourceMappingURL=expanded-tile-video.js.map