"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UgcVideoTemplate = UgcVideoTemplate;
exports.TwitterTemplate = TwitterTemplate;
exports.TikTokTemplate = TikTokTemplate;
exports.FacebookFallbackTemplate = FacebookFallbackTemplate;
exports.VideoErrorFallbackTemplate = VideoErrorFallbackTemplate;
exports.SourceVideoContent = SourceVideoContent;
exports.VideoContainer = VideoContainer;
const __1 = require("../../../");
const components_1 = require("../../components");
function getVideoData(tile) {
    if (tile.video_files?.length) {
        return tile.video_files[0];
    }
    if (tile.video && tile.video.standard_resolution) {
        return {
            width: "auto",
            height: "auto",
            mime: "video/mp4",
            url: tile.video.standard_resolution.url
        };
    }
    throw new Error("Failed to find video data");
}
function UgcVideoTemplate({ tile, onLoad }) {
    const { url, width, height, mime } = getVideoData(tile);
    return ((0, __1.createElement)("video", { style: {
            display: "none"
        }, muted: true, tileid: tile.id, class: "video-content", controls: true, preload: "none", playsinline: "playsinline", oncanplay: (event) => {
            const videoElement = event.target;
            videoElement.muted = true;
            onLoad(event);
        } },
        (0, __1.createElement)("source", { src: url, width: width.toString(), height: height.toString(), type: mime })));
}
function TwitterTemplate({ tile, onLoad, sdk }) {
    if (!tile.video) {
        return (0, __1.createElement)(VideoErrorFallbackTemplate, { tile: tile, defaultHidden: false, sdk: sdk });
    }
    const { standard_resolution } = tile.video;
    return ((0, __1.createElement)("video", { style: {
            display: "none"
        }, tileid: tile.id, class: "video-content", controls: true, preload: "none", playsinline: "playsinline", oncanplay: (event) => {
            const videoElement = event.target;
            videoElement.muted = true;
            videoElement.style.display = "flex";
            onLoad(event);
        } },
        (0, __1.createElement)("source", { src: standard_resolution.url })));
}
function TikTokTemplate({ tile, onLoad }) {
    const tiktokId = tile.tiktok_id;
    return ((0, __1.createElement)("iframe", { style: {
            display: "none"
        }, id: `tiktok-frame-${tile.id}-${tiktokId}`, loading: "lazy", tileid: tile.id, class: "video-content", frameborder: "0", allowfullscreen: true, height: "100%", onload: onLoad, allow: "autoplay" // refer https://developer.chrome.com/blog/autoplay/
        , src: `https://www.tiktok.com/player/v1/${tiktokId}?rel=0` }));
}
function FacebookFallbackTemplate({ tile, onLoad }) {
    const embedBlock = ((0, __1.createElement)("div", { class: "fb-content-wrapper" },
        (0, __1.createElement)("div", { id: "fb-root" }),
        (0, __1.createElement)("script", { async: true, defer: true, crossorigin: "anonymous", src: "https://connect.facebook.net/en_GB/sdk.js#xfbml=1&version=v21.0" }),
        (0, __1.createElement)("div", { class: "fb-video", "data-href": tile.original_link, "data-width": "500", "data-show-text": "false" },
            (0, __1.createElement)("blockquote", { cite: tile.original_link, class: "fb-xfbml-parse-ignore" },
                (0, __1.createElement)("a", { href: tile.original_link }),
                (0, __1.createElement)("p", null),
                "Posted by ",
                (0, __1.createElement)("a", { href: `https://www.facebook.com/${tile.source_user_id}` }, tile.name),
                " on",
                tile.time_ago))));
    return ((0, __1.createElement)("iframe", { style: {
            display: "none"
        }, onload: onLoad, loading: "lazy", class: "video-content", frameborder: "0", allowfullscreen: true, srcdoc: embedBlock.innerHTML }));
}
function VideoErrorFallbackTemplate({ tile, defaultHidden = true, sdk }) {
    const originalImageUrl = tile.image;
    const fallbackCss = `video-fallback-content${defaultHidden ? " hidden" : ""}`;
    return ((0, __1.createElement)("div", { class: fallbackCss },
        (0, __1.createElement)("div", { class: "center-section" },
            (0, __1.createElement)("div", { class: "play-icon" })),
        (0, __1.createElement)("a", { href: tile.original_url || tile.original_link, target: "_blank" },
            (0, __1.createElement)(components_1.ImageTemplate, { sdk: sdk, image: originalImageUrl, tile: tile }),
            (0, __1.createElement)("div", { class: "play-icon" }))));
}
function SourceVideoContent({ tile, onLoad, sdk }) {
    // handle unplayable tiktok source
    // TODO handle vide_source "tiktok"
    if (tile.source === "tiktok" || tile.video_source === "tiktok") {
        return (0, __1.createElement)(TikTokTemplate, { tile: tile, onLoad: onLoad });
    }
    if (tile.source === "youtube" && tile.youtube_id) {
        return (0, __1.createElement)(components_1.EmbedYoutube, { tileId: tile.id, videoId: tile.youtube_id, onLoad: onLoad });
    }
    if (tile.source === "facebook") {
        const videoUrlPattern = /videos\/(\d)+?/;
        if ((!tile.video_files?.length || !videoUrlPattern.test(tile.video_files[0].url)) &&
            !tile.video?.standard_resolution) {
            return (0, __1.createElement)(VideoErrorFallbackTemplate, { sdk: sdk, tile: tile, defaultHidden: false });
        }
        else {
            return (0, __1.createElement)(FacebookFallbackTemplate, { tile: tile, onLoad: onLoad });
        }
    }
    if (tile.source === "twitter") {
        return (0, __1.createElement)(TwitterTemplate, { sdk: sdk, tile: tile, onLoad: onLoad });
    }
    if (tile.video_files?.length || (tile.video && tile.video.standard_resolution)) {
        return (0, __1.createElement)(UgcVideoTemplate, { tile: tile, onLoad: onLoad });
    }
    return (0, __1.createElement)(__1.createFragment, null);
}
function VideoContainer({ tile, shopspotEnabled, sdk }) {
    return ((0, __1.createElement)("div", { class: "video-content-wrapper" },
        (0, __1.createElement)("div", { class: "center-section" },
            (0, __1.createElement)("div", { "data-tile-id": tile.id, class: "play-icon" })),
        (0, __1.createElement)("a", { href: tile.original_url, target: "_blank" },
            (0, __1.createElement)("div", { "data-tile-id": tile.id, class: "image-filler", style: { "background-image": `url('${tile.image}')` } })),
        (0, __1.createElement)("div", { class: "image" }, shopspotEnabled ? (0, __1.createElement)(components_1.ShopSpotTemplate, { sdk: sdk, shopspotEnabled: shopspotEnabled, tileId: tile.id }) : (0, __1.createElement)(__1.createFragment, null)),
        (0, __1.createElement)(SourceVideoContent, { sdk: sdk, onLoad: (event) => {
                const imageFiller = sdk.querySelector(`.image-filler[data-tile-id="${tile.id}"]`);
                if (imageFiller) {
                    imageFiller.classList.add("blurred");
                }
                const arrowIcon = sdk.querySelector(`.play-icon[data-tile-id="${tile.id}"]`);
                if (arrowIcon) {
                    arrowIcon.style.display = "none";
                }
                const videoElement = event.target;
                videoElement.style.display = "inherit";
            }, tile: tile })));
}
//# sourceMappingURL=video.templates.js.map