"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initializeSwiper = initializeSwiper;
exports.refreshSwiper = refreshSwiper;
exports.getSwiperIndexforTile = getSwiperIndexforTile;
exports.getSwiperInstance = getSwiperInstance;
exports.disableSwiper = disableSwiper;
exports.enableSwiper = enableSwiper;
exports.getMutatedId = getMutatedId;
exports.destroySwiper = destroySwiper;
exports.getClickedIndex = getClickedIndex;
exports.getInstance = getInstance;
exports.getActiveSlide = getActiveSlide;
exports.getActiveSlideElement = getActiveSlideElement;
exports.getSwiperContainer = getSwiperContainer;
exports.isSwiperLoading = isSwiperLoading;
exports.setSwiperLoadingStatus = setSwiperLoadingStatus;
exports.updateSwiperInstance = updateSwiperInstance;
const events_1 = require("../../../events");
const modules_1 = require("swiper/modules");
const loader_extension_1 = require("./loader.extension");
function addTilesUpdatedListener(sdk, id, getSlides) {
    const swiper = getInstance(sdk, id);
    sdk.addEventListener(events_1.EVENT_TILES_UPDATED, event => {
        if (event instanceof CustomEvent) {
            const tiles = event.detail.data.tiles;
            if (getSlides) {
                getSlides(sdk, tiles).forEach(slide => swiper && typeof swiper.appendSlide == "function" && swiper.appendSlide(slide));
                swiper?.update();
            }
            (0, loader_extension_1.loadAllUnloadedTiles)(sdk);
        }
    });
    if (!swiper) {
        console.warn("Swiper instance not found");
        return;
    }
    const observer = new MutationObserver(() => {
        swiper.update();
        sdk.querySelector(".tile-loading:not(.hidden)")?.classList.add("hidden");
    });
    observer.observe(sdk.querySelector(".ugc-tiles"), {
        childList: true,
        subtree: true
    });
}
function initializeSwiper(sdk, swiperProps) {
    // check if constructor is available
    if (!window.ugc.libs.Swiper) {
        console.warn("Swiper library not found. Retrying in 100ms");
        setTimeout(() => initializeSwiper(sdk, swiperProps), 100);
        return;
    }
    if (!window.ugc.libs.Swiper.prototype) {
        console.warn("Swiper library cant be initialised. Retrying in 100ms");
        setTimeout(() => initializeSwiper(sdk, swiperProps), 100);
    }
    window.ugc.swiperContainer = window.ugc?.swiperContainer ?? {};
    const { id, widgetSelector, prevButton, nextButton, paramsOverrides, getSliderTemplate } = swiperProps;
    const prev = prevButton ? widgetSelector.parentNode.querySelector(`.${prevButton}`) : undefined;
    const next = nextButton ? widgetSelector.parentNode.querySelector(`.${nextButton}`) : undefined;
    const mutatedId = getMutatedId(sdk, id);
    if (!window.ugc.swiperContainer[mutatedId]) {
        window.ugc.swiperContainer[mutatedId] = { ...(window.ugc.swiperContainer ?? {}) };
    }
    const swiperInstance = window.ugc.swiperContainer[mutatedId]?.instance;
    if (swiperInstance) {
        if (!swiperInstance.params?.enabled) {
            enableSwiper(sdk, mutatedId);
            return;
        }
        // re-initialize
        swiperInstance.destroy(true);
    }
    else {
        window.ugc.swiperContainer[mutatedId] = { pageIndex: 1 };
    }
    window.ugc.swiperContainer[mutatedId].instance = new window.ugc.libs.Swiper(widgetSelector, {
        modules: [modules_1.Navigation, modules_1.Manipulation, modules_1.Keyboard, modules_1.Mousewheel, modules_1.Autoplay, modules_1.EffectCoverflow, modules_1.Pagination],
        spaceBetween: 10,
        observer: true,
        grabCursor: true,
        allowTouchMove: true,
        direction: "horizontal",
        watchSlidesProgress: true,
        normalizeSlideIndex: true,
        watchOverflow: true,
        mousewheel: {
            enabled: false
        },
        touchStartPreventDefault: false,
        navigation: {
            enabled: !!(prev && next),
            nextEl: next,
            prevEl: prev
        },
        resizeObserver: true,
        ...paramsOverrides
    });
    if (!sdk.getCustomTemplate("expanded-tiles")) {
        addTilesUpdatedListener(sdk, id, getSliderTemplate);
    }
}
function refreshSwiper(sdk, id) {
    const instance = getSwiperInstance(sdk, id);
    if (instance) {
        instance.update();
    }
}
function getSwiperIndexforTile(swiperSelector, tileId, lookupAttr) {
    const slideElements = swiperSelector.querySelectorAll(".swiper-slide");
    const index = (() => {
        if (lookupAttr) {
            return Array.from(slideElements).findIndex(element => element.getAttribute("data-id") === tileId && element.getAttribute(lookupAttr.name) === lookupAttr.value);
        }
        return Array.from(slideElements).findIndex(element => element.getAttribute("data-id") === tileId);
    })();
    return index < 0 ? 0 : index;
}
function getSwiperInstance(sdk, id) {
    const container = getSwiperContainer(sdk, id);
    if (container && container.instance) {
        return container.instance;
    }
    console.error(`Swiper instance for id ${id} not found`);
    return null;
}
function disableSwiper(sdk, id) {
    getSwiperInstance(sdk, id)?.disable();
}
function enableSwiper(sdk, id) {
    getSwiperInstance(sdk, id)?.enable();
}
function getMutatedId(sdk, id) {
    return `${id}-wid-${sdk.getWidgetId()}`;
}
function destroySwiper(sdk, id) {
    const mutatedId = getMutatedId(sdk, id);
    if (getSwiperInstance(sdk, id)) {
        getSwiperInstance(sdk, id).destroy(true, true);
        delete window.ugc.swiperContainer[mutatedId];
    }
}
function getClickedIndex(sdk, id) {
    const instance = getInstance(sdk, id);
    if (instance) {
        const clickedSlide = instance.clickedSlide;
        const indexFromAttribute = clickedSlide.getAttribute("data-swiper-slide-index");
        return indexFromAttribute && !Number.isNaN(parseInt(indexFromAttribute))
            ? parseInt(indexFromAttribute)
            : instance.clickedIndex;
    }
    console.error(`Swiper instance for id ${id} not found`);
    return 0;
}
function getInstance(sdk, id) {
    const container = getSwiperContainer(sdk, id);
    const instance = container.instance;
    if (instance) {
        return instance;
    }
    console.error(`Swiper instance for id ${id} not found`);
}
function getActiveSlide(sdk, id) {
    return this.getInstance(sdk, id)?.realIndex || 0;
}
function getActiveSlideElement(sdk, id) {
    return getInstance(sdk, id)?.slides[getActiveSlide(sdk, id) || 0] || null;
}
function getSwiperContainer(sdk, id) {
    const mutatedId = `${id}-wid-${sdk.getWidgetId()}`;
    if (window.ugc.swiperContainer[mutatedId]) {
        return window.ugc.swiperContainer[mutatedId];
    }
    console.error(`Swiper container for id ${mutatedId} not found`);
    return null;
}
function isSwiperLoading(sdk, id) {
    return getSwiperContainer(sdk, id)?.isLoading || false;
}
function setSwiperLoadingStatus(sdk, id, isLoading) {
    if (getSwiperContainer(sdk, id)) {
        getSwiperContainer(sdk, id).isLoading = isLoading;
    }
}
function updateSwiperInstance(sdk, id, updateProps) {
    const container = getSwiperContainer(sdk, id);
    if (container && container.instance) {
        updateProps(container);
        return;
    }
    console.error(`Swiper instance for id ${id} not found`);
    return null;
}
//# sourceMappingURL=swiper.extension.js.map