"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const __1 = require("../");
function Wrapper({ id, children }) {
    return (0, __1.createElement)("div", { id: id }, children);
}
describe("JSX mapping", () => {
    it("supports direct usage", () => {
        const element = (0, __1.createElement)("div", { id: "test", className: "panel right" });
        expect(element.outerHTML).toEqual('<div id="test" class="panel right"></div>');
    });
    it("handles elements", () => {
        const element = (0, __1.createElement)("div", { id: "test", className: "panel right" });
        expect(element.outerHTML).toEqual('<div id="test" class="panel right"></div>');
    });
    it("handles function wrappers", () => {
        const element = ((0, __1.createElement)(Wrapper, { id: "test" },
            (0, __1.createElement)("span", null, "Hello World")));
        expect(element.outerHTML).toEqual('<div id="test"><span>Hello World</span></div>');
    });
    it("skips undefined children", () => {
        const element = (0, __1.createElement)("div", { id: "test" }, undefined);
        expect(element.outerHTML).toEqual('<div id="test"></div>');
    });
    it("skips false children", () => {
        const element = (0, __1.createElement)("div", { id: "test" }, false);
        expect(element.outerHTML).toEqual('<div id="test"></div>');
    });
    it("preserves zero children", () => {
        const element = (0, __1.createElement)("div", { id: "test" }, 0);
        expect(element.outerHTML).toEqual('<div id="test">0</div>');
    });
    it("registers event listeners", () => {
        let clicks = 0;
        const element = (0, __1.createElement)("div", { id: "test", onClick: () => clicks++ });
        expect(element.outerHTML).toEqual('<div id="test"></div>');
        element.click();
        expect(clicks).toEqual(1);
    });
    it("has correct event listener types", () => {
        const element = (0, __1.createElement)("div", { id: "test", onClick: e => e.preventDefault() });
        expect(element.outerHTML).toEqual('<div id="test"></div>');
    });
    it("binds styles correctly", () => {
        const element = (0, __1.createElement)("div", { id: "test", style: { color: "red", fontSize: "12px" } });
        expect(element.outerHTML).toEqual('<div id="test" style="color: red; font-size: 12px;"></div>');
    });
    it("maps htmlFor to for attribute", () => {
        const element = (0, __1.createElement)("label", { htmlFor: "test" });
        expect(element.outerHTML).toEqual('<label for="test"></label>');
    });
    it("creates fragments", () => {
        const fragment = ((0, __1.createElement)(__1.createFragment, null,
            (0, __1.createElement)("span", null, "Hello"),
            (0, __1.createElement)("span", null, "World")));
        const html = Array.from(fragment.children)
            .map(node => node.outerHTML)
            .join("");
        expect(html).toEqual("<span>Hello</span><span>World</span>");
    });
    it("creates fragment without children", () => {
        const fragment = (0, __1.createElement)(__1.createFragment, null);
        expect(fragment.children.length).toEqual(0);
    });
    it("flattens nested fragments", () => {
        const span = ((0, __1.createElement)("span", null,
            (0, __1.createElement)(__1.createFragment, null,
                (0, __1.createElement)("span", null, "Hello"),
                (0, __1.createElement)("span", null, "World")),
            (0, __1.createElement)(__1.createFragment, null,
                (0, __1.createElement)("span", null, "!"))));
        expect(span.outerHTML).toEqual("<span><span>Hello</span><span>World</span><span>!</span></span>");
        expect(span.children.length).toEqual(3);
    });
    it("handles dangerouslySetInnerHTML", () => {
        const element = (0, __1.createElement)("div", { dangerouslySetInnerHTML: { __html: "<span>Hello</span>" } });
        expect(element.outerHTML).toEqual("<div><span>Hello</span></div>");
        // malicious payload
        const element2 = (0, __1.createElement)("div", { dangerouslySetInnerHTML: { __html: "<script>alert('XSS')</script>" } });
        expect(element2.outerHTML).toEqual("<div></div>");
    });
});
//# sourceMappingURL=jsx-html.spec.js.map