"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.initialiseFeatures = initialiseFeatures;
exports.loadTemplates = loadTemplates;
exports.loadWidget = loadWidget;
const widget_features_1 = require("./libs/widget.features");
const widget_layout_1 = require("./libs/widget.layout");
const css_variables_1 = __importDefault(require("./libs/css-variables"));
const masonry_extension_1 = require("./libs/extensions/masonry/masonry.extension");
const events_1 = require("./events");
const fonts_1 = require("./fonts");
function loadMasonryCallbacks(sdk, settings) {
    const tilesUpdatedObserver = new MutationObserver(() => {
        (0, masonry_extension_1.renderMasonryLayout)(sdk);
    });
    tilesUpdatedObserver.observe(sdk.querySelector(".ugc-tiles"), {
        childList: true,
        subtree: true
    });
    settings.callbacks.onTileBgImgRenderComplete.push(() => {
        (0, masonry_extension_1.handleAllTileImageRendered)(sdk);
        setTimeout(() => (0, masonry_extension_1.handleAllTileImageRendered)(sdk), 1000);
    });
    settings.callbacks.onTileBgImageError.push(event => {
        const customEvent = event;
        const tileWithError = customEvent.detail.data.target;
        (0, masonry_extension_1.handleTileImageError)(sdk, tileWithError);
    });
    const grid = sdk.querySelector(".grid");
    if (!grid) {
        console.error("Grid element not found");
        return settings;
    }
    const observer = new ResizeObserver(() => {
        (0, masonry_extension_1.renderMasonryLayout)(sdk);
    });
    observer.observe(grid);
    return settings;
}
function mergeSettingsWithDefaults(settings) {
    return {
        features: {
            showTitle: true,
            preloadImages: true,
            disableWidgetIfNotEnabled: true,
            addNewTilesAutomatically: true,
            handleLoadMore: true,
            hideBrokenImages: true,
            loadTileContent: true,
            loadTimephrase: true,
            ...settings?.features
        },
        callbacks: {
            ...events_1.callbackDefaults,
            ...settings?.callbacks
        },
        extensions: {
            swiper: false,
            masonry: false,
            ...settings?.extensions
        },
        templates: settings?.templates ?? {},
        config: settings?.config ?? {}
    };
}
async function loadFeatures(sdk, settings) {
    const { showTitle, preloadImages, addNewTilesAutomatically, handleLoadMore, hideBrokenImages, loadTileContent, loadTimephrase } = settings.features;
    sdk.setPreloadImages(preloadImages);
    sdk.setHideBrokenTiles(hideBrokenImages);
    const { show_shopspots: showShopspotsInline } = sdk.getInlineTileConfig();
    if (showShopspotsInline) {
        sdk.addLoadedComponents(["shopspots"]);
    }
    if (loadTileContent) {
        sdk.addLoadedComponents(["tile-content", "timephrase", "tags", "share-menu"]);
    }
    else if (loadTimephrase) {
        sdk.addLoadedComponents(["timephrase"]);
    }
    if (showTitle) {
        (0, widget_features_1.loadTitle)(sdk);
    }
    (0, widget_features_1.loadExpandedTileFeature)(sdk);
    if (addNewTilesAutomatically) {
        (0, widget_features_1.addAutoAddTileFeature)(sdk);
    }
    if (handleLoadMore) {
        sdk.addLoadedComponents(["load-more"]);
        (0, widget_features_1.addLoadMoreButtonFeature)(sdk);
    }
    return settings;
}
function loadExtensions(sdk, settings) {
    const { extensions } = settings;
    if (extensions?.masonry) {
        settings = loadMasonryCallbacks(sdk, settings);
        (0, masonry_extension_1.renderMasonryLayout)(sdk);
    }
    return settings;
}
function initialiseFeatures(settings) {
    if (Object.keys(settings.features ?? {}).length === 0) {
        settings.features = {
            showTitle: true,
            preloadImages: true,
            disableWidgetIfNotEnabled: true,
            addNewTilesAutomatically: true,
            handleLoadMore: true,
            hideBrokenImages: true,
            loadTileContent: true,
            loadTimephrase: true
        };
    }
    return settings;
}
function loadTemplates(sdk, settings) {
    if (settings.templates && Object.keys(settings.templates).length) {
        Object.entries(settings.templates).forEach(([key, customTemplate]) => {
            if (!customTemplate) {
                return;
            }
            const { template } = customTemplate;
            if (template) {
                sdk.addTemplateToComponent(template, key);
            }
        });
    }
}
function addConfigStyles(sdk, settings) {
    const { style } = settings.config;
    if (style) {
        sdk.updateWidgetStyle(style);
    }
}
function addConfigExpandedTileSettings(sdk, settings) {
    const { expandedTile } = settings.config;
    if (expandedTile) {
        sdk.updateExpandedTileOptions(expandedTile);
    }
}
function addConfigInlineTileSettings(sdk, settings) {
    const { inlineTile } = settings.config;
    if (inlineTile) {
        sdk.updateInlineTileOptions(inlineTile);
    }
}
function addConfigFilter(sdk, settings) {
    const { filter } = settings.config;
    if (filter && filter.media) {
        sdk.setMediaType(filter.media);
    }
}
function loadWidget(sdk, settings) {
    const settingsWithDefaults = mergeSettingsWithDefaults(settings);
    addConfigStyles(sdk, settingsWithDefaults);
    addConfigExpandedTileSettings(sdk, settingsWithDefaults);
    addConfigInlineTileSettings(sdk, settingsWithDefaults);
    (0, widget_layout_1.addCSSVariablesToPlacement)(sdk, (0, css_variables_1.default)(sdk, settings?.features));
    addConfigFilter(sdk, settingsWithDefaults);
    loadTemplates(sdk, settingsWithDefaults);
    loadFeatures(sdk, settingsWithDefaults);
    loadExtensions(sdk, settingsWithDefaults);
    (0, events_1.loadListeners)(sdk, settingsWithDefaults);
    (0, fonts_1.injectFontFaces)(document.head, settings?.config?.fonts);
    (0, fonts_1.injectFontFaces)(sdk.getShadowRoot(), settings?.config?.fonts);
}
//# sourceMappingURL=widget-loader.js.map