import { destroySwiper, getActiveSlide, getActiveSlideElement, getSwiperIndexforTile, initializeSwiper, updateSwiperInstance } from "../../extensions/swiper/swiper.extension";
import { waitForElm } from "../../widget.features";
import { muteTiktokVideo, unMuteTiktokVideo } from "./tiktok-message";
import { EVENT_LOAD_MORE } from "../../../events";
import { getExpandedSlides } from "./base.template";
import { controlVideoPlayback, setupTikTokPlayerReadyEvent, setupVideoEvents, setupYoutubeEvents } from "./expanded-tile-video";
/**
 * Initialize/re-initialize swiper for loading expanded tiles
 *
 * @param { string } initialTileId  - id of the tile that should be displayed after loading swiper
 * @param { LookupAttr } lookupAttr - additional attribute lookup options for finding the first slide to load
 * @param { LookupAttr.name } lookupAttr.name - name of the attribute for e.g. data-yt-id or data-tiktok-id
 * @param { LookupAttr.value } lookupAttr.value - required value of the attribute
 */
function initializeSwiperForExpandedTiles(sdk, initialTileId, lookupAttr) {
    const expandedTile = sdk.getExpandedTiles();
    const expandedTileWrapper = expandedTile?.querySelector(".expanded-tile-wrapper");
    if (!expandedTile || !expandedTileWrapper) {
        throw new Error("The expanded tile element not found");
    }
    const widgetSelector = expandedTile.querySelector(".swiper-expanded");
    if (!widgetSelector) {
        throw new Error("Failed to find widget UI element. Failed to initialise Glide");
    }
    const isStory = expandedTileWrapper.getAttribute("variation") === "story";
    if (isStory) {
        initalizeStoryExpandedTile(sdk, initialTileId, widgetSelector, expandedTileWrapper, lookupAttr);
    }
    else {
        initalizeExpandedTile(sdk, initialTileId, widgetSelector, lookupAttr);
    }
}
function initalizeExpandedTile(sdk, initialTileId, widgetSelector, lookupAttr) {
    initializeSwiper(sdk, {
        id: "expanded",
        widgetSelector,
        mode: "expanded",
        prevButton: "swiper-expanded-button-prev",
        nextButton: "swiper-expanded-button-next",
        paramsOverrides: {
            loop: false,
            slidesPerView: 1,
            autoHeight: true,
            keyboard: {
                enabled: true,
                onlyInViewport: false
            },
            on: {
                reachEnd: () => {
                    sdk.triggerEvent(EVENT_LOAD_MORE);
                },
                beforeInit: (swiper) => {
                    const tileIndex = initialTileId ? getSwiperIndexforTile(widgetSelector, initialTileId, lookupAttr) : 0;
                    swiper.slideToLoop(tileIndex, 0, false);
                },
                autoplayTimeLeft: (swiper, _timeLeft, percentage) => {
                    storyAutoplayProgress(swiper, percentage);
                },
                navigationNext: (swiper) => swiperNavigationHandler(sdk, swiper),
                navigationPrev: (swiper) => swiperNavigationHandler(sdk, swiper)
            }
        },
        getSliderTemplate: getExpandedSlides
    });
}
function initalizeStoryExpandedTile(sdk, initialTileId, widgetSelector, expandedTileWrapper, lookupAttr) {
    initializeSwiper(sdk, {
        id: "expanded",
        widgetSelector,
        mode: "expanded",
        prevButton: "swiper-expanded-button-prev",
        nextButton: "swiper-expanded-button-next",
        paramsOverrides: {
            slidesPerView: "auto",
            autoHeight: true,
            autoplay: {
                delay: 5000
            },
            centeredSlides: true,
            effect: "coverflow",
            coverflowEffect: {
                rotate: 0,
                scale: 0.8,
                stretch: -1,
                depth: 1,
                modifier: 1,
                slideShadows: false
            },
            keyboard: {
                enabled: true,
                onlyInViewport: false
            },
            on: {
                beforeInit: (swiper) => {
                    const tileIndex = initialTileId ? getSwiperIndexforTile(widgetSelector, initialTileId, lookupAttr) : 0;
                    swiper.slideToLoop(tileIndex, 0, false);
                },
                reachEnd: () => {
                    sdk.triggerEvent(EVENT_LOAD_MORE);
                },
                afterInit: (swiper) => {
                    registerStoryControls(sdk, expandedTileWrapper, swiper);
                },
                autoplayTimeLeft: (swiper, _timeLeft, percentage) => {
                    storyAutoplayProgress(swiper, percentage);
                },
                slideChange: (swiper) => swiperNavigationHandler(sdk, swiper),
                autoplay: (swiper) => swiperNavigationHandler(sdk, swiper)
            }
        },
        getSliderTemplate: getExpandedSlides
    });
}
async function swiperNavigationHandler(sdk, swiper) {
    controlVideoPlayback(sdk, swiper);
    const tileId = getTileIdFromSlide(swiper, swiper.realIndex);
    if (!tileId) {
        throw Error("Tile ID is not found in next slide from swiper");
    }
    const tile = sdk.getTileById(tileId);
    if (!tile) {
        throw Error("Tile is not found in next slide from swiper");
    }
    sdk.setTile(tile);
}
function storyAutoplayProgress(swiper, progress) {
    const activeSlideElement = swiper.slides[swiper.realIndex];
    const progressLine = activeSlideElement.querySelector(".story-autoplay-progress > .progress-content");
    if (!progressLine) {
        return;
    }
    progressLine.style.width = `${100 - Math.round(progress * 100)}%`;
}
function registerStoryControls(sdk, tileWrapper, swiper) {
    const storyCtrls = tileWrapper.querySelector(".story-controls");
    if (!storyCtrls) {
        return;
    }
    const playCtrl = storyCtrls.querySelector(".play-ctrl");
    const pauseCtrl = storyCtrls.querySelector(".pause-ctrl");
    const volumeCtrl = storyCtrls.querySelector(".volume-ctrl");
    const muteCtrl = storyCtrls.querySelector(".mute-ctrl");
    playCtrl?.addEventListener("click", () => {
        playCtrl.classList.add("hidden");
        pauseCtrl?.classList.remove("hidden");
        swiper.autoplay.start();
    });
    pauseCtrl?.addEventListener("click", () => {
        pauseCtrl.classList.add("hidden");
        playCtrl?.classList.remove("hidden");
        swiper.autoplay.stop();
    });
    volumeCtrl?.addEventListener("click", () => {
        volumeCtrl.classList.add("hidden");
        muteCtrl?.classList.remove("hidden");
        updateSwiperInstance(sdk, "expanded", (swiperData) => {
            swiperData.muted = true;
        });
        const videoEles = tileWrapper.querySelectorAll("video");
        videoEles.forEach(ele => {
            ele.muted = true;
        });
        const iFramePlayers = tileWrapper.querySelectorAll(`iframe.video-content`);
        iFramePlayers.forEach(iFramePlayer => {
            const iFramePlayerId = iFramePlayer.getAttribute("id");
            if (iFramePlayerId) {
                if (iFramePlayerId.includes("yt-frame")) {
                    const iFramePlayerWindow = iFramePlayer.contentWindow;
                    iFramePlayerWindow.mute();
                }
                else if (iFramePlayerId.includes("tiktok-frame")) {
                    const iFramePlayerWindow = iFramePlayer.contentWindow;
                    muteTiktokVideo(iFramePlayerWindow);
                }
            }
        });
    });
    muteCtrl?.addEventListener("click", () => {
        muteCtrl.classList.add("hidden");
        volumeCtrl?.classList.remove("hidden");
        updateSwiperInstance(sdk, "expanded", (swiperData) => {
            swiperData.muted = false;
        });
        const videoEles = tileWrapper.querySelectorAll("video");
        videoEles.forEach(ele => {
            ele.muted = false;
        });
        const iFramePlayers = tileWrapper.querySelectorAll(`iframe.video-content`);
        iFramePlayers.forEach(iFramePlayer => {
            const iFramePlayerId = iFramePlayer.getAttribute("id");
            if (iFramePlayerId) {
                if (iFramePlayerId.includes("yt-frame")) {
                    const iFramePlayerWindow = iFramePlayer.contentWindow;
                    iFramePlayerWindow.unMute();
                }
                else if (iFramePlayerId.includes("tiktok-frame")) {
                    const iFramePlayerWindow = iFramePlayer.contentWindow;
                    unMuteTiktokVideo(iFramePlayerWindow);
                }
            }
        });
    });
    handleAutoplayProgress(tileWrapper, swiper, playCtrl);
}
/**
 * pause autoplay progress when hover over active slide
 * resume autoplay progress when mouse leave the active slide
 * @param tileWrapper
 * @param swiper
 * @param playCtrl
 */
function handleAutoplayProgress(tileWrapper, swiper, playCtrl) {
    const swiperWrapperEle = tileWrapper.querySelector(".swiper-wrapper");
    swiperWrapperEle?.addEventListener("mouseover", (e) => {
        const eventTarget = e.target;
        const panelActiveEle = eventTarget ? eventTarget.closest(".swiper-slide-active") : null;
        if (panelActiveEle) {
            if (!swiper.autoplay.paused) {
                swiper.autoplay.pause();
            }
        }
        else {
            if (playCtrl?.classList.contains("hidden")) {
                if (swiper.autoplay.paused) {
                    swiper.autoplay.resume();
                }
            }
        }
    });
    swiperWrapperEle?.addEventListener("mouseleave", () => {
        if (playCtrl?.classList.contains("hidden")) {
            if (swiper.autoplay.paused) {
                swiper.autoplay.resume();
            }
        }
    });
}
/*
 Get Tile ID
*/
export function getTileIdFromSlide(swiper, index) {
    const element = swiper.slides[index];
    return element.getAttribute("data-id");
}
/**
 * Triggered when an inline tile is clicked
 * Adds background overlay for expanded tile and initializes swiper for expanded tile
 *
 * @param { string } tileId - the id of clicked inline tile and the tile that will be displayed on expanded tile load
 */
export function onTileExpand(sdk, tileId) {
    const expandedTile = sdk.getExpandedTiles();
    const body = document.querySelector("body");
    if (body) {
        body.style.overflow = "hidden";
    }
    const overlay = expandedTile.parentElement;
    overlay.showModal();
    overlay.classList.add("expanded-tile-overlay");
    waitForElm(expandedTile, [".swiper-expanded"], () => {
        const tileElement = expandedTile.shadowRoot?.querySelector(`.swiper-slide[data-id="${tileId}"]`);
        const youtubeId = tileElement?.getAttribute("data-yt-id");
        const tiktokId = tileElement?.getAttribute("data-tiktok-id");
        if (youtubeId) {
            const lookupYtAttr = { name: "data-yt-id", value: youtubeId };
            initializeSwiperForExpandedTiles(sdk, tileId, lookupYtAttr);
        }
        else if (tiktokId) {
            const lookupTiktokAttr = { name: "data-tiktok-id", value: tiktokId };
            initializeSwiperForExpandedTiles(sdk, tileId, lookupTiktokAttr);
        }
        else {
            initializeSwiperForExpandedTiles(sdk, tileId);
        }
    });
}
/**
 * Triggered after all slides in expanded tiles are loaded
 * Setup onload and onerror events for media sources (video/youtube/tiktok)
 */
export function onTileRendered(event) {
    const widgetSelectorId = event.detail.widgetSelector;
    const sdk = window.ugc.getWidgetBySelector(widgetSelectorId).sdk;
    const expandedTilesElement = sdk.getExpandedTiles();
    const tiles = expandedTilesElement.querySelectorAll(".swiper-slide");
    const widgetSelector = expandedTilesElement.querySelector(".swiper-expanded");
    if (!widgetSelector) {
        throw new Error("Widget selector for expanded tile (swiper-expanded) is not found");
    }
    setupTikTokPlayerReadyEvent(sdk);
    tiles?.forEach(tile => {
        setupVideoEvents(sdk, tile, widgetSelector);
        setupYoutubeEvents(sdk, tile, widgetSelector);
    });
}
/**
 * Reduces visibility of swiper controls when share menu is opened
 */
export function reduceBackgroundControlsVisibility(sdk, sourceId) {
    if (!isValidEventSource(sdk, sourceId)) {
        return;
    }
    const expandedTile = sdk.getExpandedTiles();
    const wrapper = expandedTile.querySelector(".expanded-tile-wrapper");
    if (!wrapper) {
        return;
    }
    const navigationPrevButton = wrapper.querySelector(".swiper-expanded-button-prev");
    const navigationNextButton = wrapper.querySelector(".swiper-expanded-button-next");
    const exitTileButton = wrapper.querySelector(".exit");
    navigationNextButton?.classList.add("swiper-button-disabled");
    navigationPrevButton?.classList.add("swiper-button-disabled");
    if (exitTileButton) {
        exitTileButton.style.opacity = "0.4";
    }
}
/**
 * Resets visibility of swiper controls when share menu is closed
 */
export function resetBackgroundControlsVisibility(sdk, sourceId) {
    if (!isValidEventSource(sdk, sourceId)) {
        return;
    }
    const expandedTile = sdk.getExpandedTiles();
    const wrapper = expandedTile.querySelector(".expanded-tile-wrapper");
    if (!wrapper) {
        return;
    }
    const navigationPrevButton = wrapper.querySelector(".swiper-expanded-button-prev");
    const navigationNextButton = wrapper.querySelector(".swiper-expanded-button-next");
    const exitTileButton = wrapper.querySelector(".exit");
    navigationNextButton?.classList.remove("swiper-button-disabled");
    navigationPrevButton?.classList.remove("swiper-button-disabled");
    if (exitTileButton) {
        exitTileButton.removeAttribute("style");
    }
}
/**
 * Checks if the source id from the event matches the active slide tile id
 * TODO - Improve this if the tile id can be repeated real time
 *
 * @param { string } sourceId - an event identifier. usually a tileId or a combinations of ids
 * @returns
 */
function isValidEventSource(sdk, sourceId) {
    const activeSlideElement = getActiveSlideElement(sdk, "expanded");
    return activeSlideElement?.getAttribute("data-id") === sourceId;
}
/**
 * Checks if the supplied tile element is currently active in the slide
 *
 * @param { Element } tile - tile element to check
 * @param { HTMLElement } widgetSelector - the container of the swiper element
 * @param { LookupAttr } lookupAttr - additional attribute lookup options for finding the first slide to load
 * @param { LookupAttr.name } lookupAttr.name - name of the attribute for e.g. data-yt-id or data-tiktok-id
 * @param { LookupAttr.value } lookupAttr.value - required value of the attribute
 * @returns true if the supplied tile element is the currently displayed element. false, otherwise.
 */
export function isActiveTile(sdk, tile, widgetSelector, lookupAttr) {
    const tileId = tile.getAttribute("data-id");
    if (lookupAttr) {
        const originalLookupAttrValue = tile.getAttribute(lookupAttr.name);
        const activeSwiperElement = getActiveSlideElement(sdk, "expanded");
        const activeElementTileId = activeSwiperElement?.getAttribute("data-id");
        const activeElementLookupAttrValue = activeSwiperElement?.getAttribute(lookupAttr.name);
        return originalLookupAttrValue === activeElementLookupAttrValue && tileId === activeElementTileId;
    }
    const tileIndex = tileId ? getSwiperIndexforTile(widgetSelector, tileId, lookupAttr) : 0;
    return getActiveSlide(sdk, "expanded") === tileIndex;
}
/**
 * Triggered when expanded tile is closed
 * Destroys swiper instance for expanded tile and removes background overlay
 */
export function onTileClosed(event) {
    const widgetSelectorId = event.detail.widgetSelector;
    const sdk = window.ugc.getWidgetBySelector(widgetSelectorId).sdk;
    const expandedTile = sdk.getExpandedTiles();
    const overlay = expandedTile.parentElement;
    overlay.close();
    overlay.classList.remove("expanded-tile-overlay");
    const body = document.querySelector("body");
    if (body) {
        body.style.overflow = "auto";
    }
    destroySwiper(sdk, "expanded");
}
//# sourceMappingURL=expanded-swiper.loader.js.map