import { createElement, createFragment } from "../../../";
import { EmbedYoutube, ImageTemplate, ShopSpotTemplate } from "../../components";
function getVideoData(tile) {
    if (tile.video_files?.length) {
        return tile.video_files[0];
    }
    if (tile.video && tile.video.standard_resolution) {
        return {
            width: "auto",
            height: "auto",
            mime: "video/mp4",
            url: tile.video.standard_resolution.url
        };
    }
    throw new Error("Failed to find video data");
}
export function UgcVideoTemplate({ tile, onLoad }) {
    const { url, width, height, mime } = getVideoData(tile);
    return (createElement("video", { style: {
            display: "none"
        }, muted: true, tileid: tile.id, class: "video-content", controls: true, preload: "none", playsinline: "playsinline", oncanplay: (event) => {
            const videoElement = event.target;
            videoElement.muted = true;
            onLoad(event);
        } },
        createElement("source", { src: url, width: width.toString(), height: height.toString(), type: mime })));
}
export function TwitterTemplate({ tile, onLoad, sdk }) {
    if (!tile.video) {
        return createElement(VideoErrorFallbackTemplate, { tile: tile, defaultHidden: false, sdk: sdk });
    }
    const { standard_resolution } = tile.video;
    return (createElement("video", { style: {
            display: "none"
        }, tileid: tile.id, class: "video-content", controls: true, preload: "none", playsinline: "playsinline", oncanplay: (event) => {
            const videoElement = event.target;
            videoElement.muted = true;
            videoElement.style.display = "flex";
            onLoad(event);
        } },
        createElement("source", { src: standard_resolution.url })));
}
export function TikTokTemplate({ tile, onLoad }) {
    const tiktokId = tile.tiktok_id;
    return (createElement("iframe", { style: {
            display: "none"
        }, id: `tiktok-frame-${tile.id}-${tiktokId}`, loading: "lazy", tileid: tile.id, class: "video-content", frameborder: "0", allowfullscreen: true, height: "100%", onload: onLoad, allow: "autoplay" // refer https://developer.chrome.com/blog/autoplay/
        , src: `https://www.tiktok.com/player/v1/${tiktokId}?rel=0` }));
}
export function FacebookFallbackTemplate({ tile, onLoad }) {
    const embedBlock = (createElement("div", { class: "fb-content-wrapper" },
        createElement("div", { id: "fb-root" }),
        createElement("script", { async: true, defer: true, crossorigin: "anonymous", src: "https://connect.facebook.net/en_GB/sdk.js#xfbml=1&version=v21.0" }),
        createElement("div", { class: "fb-video", "data-href": tile.original_link, "data-width": "500", "data-show-text": "false" },
            createElement("blockquote", { cite: tile.original_link, class: "fb-xfbml-parse-ignore" },
                createElement("a", { href: tile.original_link }),
                createElement("p", null),
                "Posted by ",
                createElement("a", { href: `https://www.facebook.com/${tile.source_user_id}` }, tile.name),
                " on",
                tile.time_ago))));
    return (createElement("iframe", { style: {
            display: "none"
        }, onload: onLoad, loading: "lazy", class: "video-content", frameborder: "0", allowfullscreen: true, srcdoc: embedBlock.innerHTML }));
}
export function VideoErrorFallbackTemplate({ tile, defaultHidden = true, sdk }) {
    const originalImageUrl = tile.image;
    const fallbackCss = `video-fallback-content${defaultHidden ? " hidden" : ""}`;
    return (createElement("div", { class: fallbackCss },
        createElement("div", { class: "center-section" },
            createElement("div", { class: "play-icon" })),
        createElement("a", { href: tile.original_url || tile.original_link, target: "_blank" },
            createElement(ImageTemplate, { sdk: sdk, image: originalImageUrl, tile: tile }),
            createElement("div", { class: "play-icon" }))));
}
export function SourceVideoContent({ tile, onLoad, sdk }) {
    // handle unplayable tiktok source
    // TODO handle vide_source "tiktok"
    if (tile.source === "tiktok" || tile.video_source === "tiktok") {
        return createElement(TikTokTemplate, { tile: tile, onLoad: onLoad });
    }
    if (tile.source === "youtube" && tile.youtube_id) {
        return createElement(EmbedYoutube, { tileId: tile.id, videoId: tile.youtube_id, onLoad: onLoad });
    }
    if (tile.source === "facebook") {
        const videoUrlPattern = /videos\/(\d)+?/;
        if ((!tile.video_files?.length || !videoUrlPattern.test(tile.video_files[0].url)) &&
            !tile.video?.standard_resolution) {
            return createElement(VideoErrorFallbackTemplate, { sdk: sdk, tile: tile, defaultHidden: false });
        }
        else {
            return createElement(FacebookFallbackTemplate, { tile: tile, onLoad: onLoad });
        }
    }
    if (tile.source === "twitter") {
        return createElement(TwitterTemplate, { sdk: sdk, tile: tile, onLoad: onLoad });
    }
    if (tile.video_files?.length || (tile.video && tile.video.standard_resolution)) {
        return createElement(UgcVideoTemplate, { tile: tile, onLoad: onLoad });
    }
    return createElement(createFragment, null);
}
export function VideoContainer({ tile, shopspotEnabled, sdk }) {
    return (createElement("div", { class: "video-content-wrapper" },
        createElement("div", { class: "center-section" },
            createElement("div", { "data-tile-id": tile.id, class: "play-icon" })),
        createElement("a", { href: tile.original_url, target: "_blank" },
            createElement("div", { "data-tile-id": tile.id, class: "image-filler", style: { "background-image": `url('${tile.image}')` } })),
        createElement("div", { class: "image" }, shopspotEnabled ? createElement(ShopSpotTemplate, { sdk: sdk, shopspotEnabled: shopspotEnabled, tileId: tile.id }) : createElement(createFragment, null)),
        createElement(SourceVideoContent, { sdk: sdk, onLoad: (event) => {
                const imageFiller = sdk.querySelector(`.image-filler[data-tile-id="${tile.id}"]`);
                if (imageFiller) {
                    imageFiller.classList.add("blurred");
                }
                const arrowIcon = sdk.querySelector(`.play-icon[data-tile-id="${tile.id}"]`);
                if (arrowIcon) {
                    arrowIcon.style.display = "none";
                }
                const videoElement = event.target;
                videoElement.style.display = "inherit";
            }, tile: tile })));
}
//# sourceMappingURL=video.templates.js.map